@@ -33,7 +33,7 @@ __PACKAGE__->config(
             },
             quxx => {
                 password => "ding",
-                roles => [qw/moose_trainer/],
+                roles => [qw/zoo_worker moose_trainer/],
                 os => "osx",
             },
         },
@@ -47,7 +47,7 @@ __PACKAGE__->setup;
 
 __PACKAGE__->allow_access_if("/", sub { 1 }); # just to test that / can be applied to
 
-__PACKAGE__->deny_access_unless("/lioncage", [qw/zoo_worker lion_tamer/]); # only highly trained personnel can enter
+__PACKAGE__->deny_access_unless_any("/lioncage", [qw/zoo_worker lion_tamer/]);
 
 # this now in config
 # __PACKAGE__->deny_access_unless("/restricted", sub { 0 }); # no one can access
