@@ -1,5 +1,8 @@
 package ACLTestApp::Controller::Root;
 
+use strict;
+use warnings;
+no warnings 'uninitialized';
 use base 'Catalyst::Controller';
 __PACKAGE__->config->{namespace} = '';
 
